pub struct QuerySigningInfosRequest {
pub pagination: Option<PageRequest>,
}Expand description
QuerySigningInfosRequest is the request type for the Query/SigningInfos RPC method
Fields
pagination: Option<PageRequest>Trait Implementations
impl Clone for QuerySigningInfosRequest
impl Clone for QuerySigningInfosRequest
fn clone(&self) -> QuerySigningInfosRequest
fn clone(&self) -> QuerySigningInfosRequest
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for QuerySigningInfosRequest
impl Debug for QuerySigningInfosRequest
impl Default for QuerySigningInfosRequest
impl Default for QuerySigningInfosRequest
fn default() -> QuerySigningInfosRequest
fn default() -> QuerySigningInfosRequest
Returns the “default value” for a type. Read more
impl Message for QuerySigningInfosRequest
impl Message for QuerySigningInfosRequest
fn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
fn clear(&mut self)
fn clear(&mut self)
Clears the message, resetting all fields to their default.
sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
Encodes the message to a buffer. Read more
sourcefn encode_to_vec(&self) -> Vec<u8, Global> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8, Global> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8, Global> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8, Global> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
Decodes an instance of the message from a buffer. Read more
sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moresourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self. Read moreimpl PartialEq<QuerySigningInfosRequest> for QuerySigningInfosRequest
impl PartialEq<QuerySigningInfosRequest> for QuerySigningInfosRequest
fn eq(&self, other: &QuerySigningInfosRequest) -> bool
fn eq(&self, other: &QuerySigningInfosRequest) -> bool
impl StructuralPartialEq for QuerySigningInfosRequest