Enum boot_core::cosmos_modules::tx::OrderBy
pub enum OrderBy {
Unspecified,
Asc,
Desc,
}Expand description
OrderBy defines the sorting order
Variants
Unspecified
ORDER_BY_UNSPECIFIED specifies an unknown sorting order. OrderBy defaults to ASC in this case.
Asc
ORDER_BY_ASC defines ascending order
Desc
ORDER_BY_DESC defines descending order
Implementations
impl OrderBy
impl OrderBy
impl OrderBy
impl OrderBy
pub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.