pub struct AuthInfo {
    pub signer_infos: Vec<SignerInfo, Global>,
    pub fee: Option<Fee>,
}
AuthInfo describes the fee and signer modes that are used to sign a transaction.

Fields

signer_infos: Vec<SignerInfo, Global>

signer_infos defines the signing modes for the required signers. The number and order of elements must match the required signers from TxBody’s messages. The first element is the primary signer and the one which pays the fee.

fee: Option<Fee>

Fee is the fee and gas limit for the transaction. The first signer is the primary signer and the one which pays the fee. The fee can be calculated based on the cost of evaluating the body and doing signature verification of the signers. This can be estimated via simulation.