pub struct SignDoc {
    pub body_bytes: Vec<u8, Global>,
    pub auth_info_bytes: Vec<u8, Global>,
    pub chain_id: String,
    pub account_number: u64,
}
SignDoc is the type used for generating sign bytes for SIGN_MODE_DIRECT.

Fields

body_bytes: Vec<u8, Global>

body_bytes is protobuf serialization of a TxBody that matches the representation in TxRaw.

auth_info_bytes: Vec<u8, Global>

auth_info_bytes is a protobuf serialization of an AuthInfo that matches the representation in TxRaw.

chain_id: String

chain_id is the unique identifier of the chain this transaction targets. It prevents signed transactions from being used on another chain by an attacker

account_number: u64

account_number is the account number of the account in state