Struct boot_core::cosmos_modules::tx::Tx
pub struct Tx {
pub body: Option<TxBody>,
pub auth_info: Option<AuthInfo>,
pub signatures: Vec<Vec<u8, Global>, Global>,
}Expand description
Tx is the standard type used for broadcasting transactions.
Fields
body: Option<TxBody>body is the processable content of the transaction
auth_info: Option<AuthInfo>auth_info is the authorization related content of the transaction, specifically signers, signer modes and fee
signatures: Vec<Vec<u8, Global>, Global>signatures is a list of signatures that matches the length and order of AuthInfo’s signer_infos to allow connecting signature meta information like public key and signing mode by position.